[![Build Status](https://github.com/jupyter-server/jupyverse/workflows/test/badge.svg)](https://github.com/jupyter-server/jupyverse/actions)

# jupyverse

A set of [Asphalt](https://asphalt.readthedocs.io) components implementing a Jupyter server.

Try it online:
- JupyterLab frontend: [![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/jupyter-server/jupyverse/HEAD?urlpath=jupyverse-jlab)
- RetroLab frontend: [![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/jupyter-server/jupyverse/HEAD?urlpath=jupyverse-rlab)

Documentation is available [here](https://davidbrochart.github.io/jupyverse).

## Motivation

For the motivations behind this project, please refer to this issue in the
[Jupyter server team compass](https://github.com/jupyter-server/team-compass/issues/11).
